@@ -308,6 +308,7 @@ def load_config_work_requirement() -> ConfigWorkRequirement:
             providers=wr_section.get(PROVIDERS, None),
             ram=wr_section.get(RAM, None),
             regions=wr_section.get(REGIONS, None),
+            retryable_errors=wr_section.get(RETRYABLE_ERRORS, None),
             set_task_names=wr_section.get(SET_TASK_NAMES, True),
             task_batch_size=task_batch_size,
             task_count=task_count,
@@ -318,7 +319,6 @@ def load_config_work_requirement() -> ConfigWorkRequirement:
             task_group_count=task_group_count,
             task_group_name=wr_section.get(TASK_GROUP_NAME, None),
             task_name=wr_section.get(TASK_NAME, None),
-            task_retry_error_matchers=wr_section.get(TASK_RETRY_ERROR_MATCHERS, None),
             task_timeout=wr_section.get(TASK_TIMEOUT, None),
             task_type=task_type,
             tasks_per_worker=wr_section.get(TASKS_PER_WORKER, None),
